package com.inspect.patrol.mapper;

import com.inspect.patrol.domain.PatrolPosInfrared;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface PatrolPosInfraredMapper {
    PatrolPosInfrared selectPatrolPosInfraredByPatrolPosInfraredId(Long id);

    List<PatrolPosInfrared> selectPatrolPosInfraredList(PatrolPosInfrared infrared);

    int insertPatrolPosInfrared(PatrolPosInfrared infrared);

    int updatePatrolPosInfrared(PatrolPosInfrared infrared);

    int deletePatrolPosInfraredByPatrolPosInfraredId(Long id);

    int deletePatrolPosInfraredByPatrolPosInfraredIds(Long[] ids);
}
